==> express-audio-1.14.0-sources.jar: im/zego/zegoexpress/entity/ZegoPublishStreamQuality.java <==
package im.zego.zegoexpress.entity;

import im.zego.zegoexpress.constants.*;
import im.zego.zegoexpress.callback.*;
import im.zego.zegoexpress.entity.*;
import java.nio.*;
import java.util.*;
import org.json.*;
import im.zego.zegoexpress.*;
import im.zego.zegoexpress.internal.*;
import android.app.Application;
import android.graphics.*;

/**
 * Published stream quality information
 *
 * Audio and video parameters and network quality, etc.
 */
public class ZegoPublishStreamQuality {

    /** Video capture frame rate. The unit of frame rate is f/s */
    public double videoCaptureFPS;

    /** Video encoding frame rate. The unit of frame rate is f/s */
    public double videoEncodeFPS;

    /** Video transmission frame rate. The unit of frame rate is f/s */
    public double videoSendFPS;

    /** Video bit rate in kbps */
    public double videoKBPS;

    /** Audio capture frame rate. The unit of frame rate is f/s */
    public double audioCaptureFPS;

    /** Audio transmission frame rate. The unit of frame rate is f/s */
    public double audioSendFPS;

    /** Audio bit rate in kbps */
    public double audioKBPS;

    /** Local to server delay, in milliseconds */
    public int rtt;

    /** Packet loss rate, in percentage, 0.0 ~ 1.0 */
    public double packetLostRate;

    /** Published stream quality level */
    public ZegoStreamQualityLevel level;

    /** Whether to enable hardware encoding */
    public boolean isHardwareEncode;

    /** Total number of bytes sent, including audio, video, SEI */
    public double totalSendBytes;

    /** Number of audio bytes sent */
    public double audioSendBytes;

    /** Number of video bytes sent */
    public double videoSendBytes;

}

==> express-audio-2.1.1-sources.jar: im/zego/zegoexpress/entity/ZegoPublishStreamQuality.java <==
package im.zego.zegoexpress.entity;

import im.zego.zegoexpress.constants.*;
import im.zego.zegoexpress.callback.*;
import im.zego.zegoexpress.entity.*;
import java.nio.*;
import java.util.*;
import org.json.*;
import im.zego.zegoexpress.*;
import im.zego.zegoexpress.internal.*;
import android.app.Application;
import android.graphics.*;

/**
 * Published stream quality information.
 *
 * Audio and video parameters and network quality, etc.
 */
public class ZegoPublishStreamQuality {

    /** Video capture frame rate. The unit of frame rate is f/s */
    public double videoCaptureFPS;

    /** Video encoding frame rate. The unit of frame rate is f/s */
    public double videoEncodeFPS;

    /** Video transmission frame rate. The unit of frame rate is f/s */
    public double videoSendFPS;

    /** Video bit rate in kbps */
    public double videoKBPS;

    /** Audio capture frame rate. The unit of frame rate is f/s */
    public double audioCaptureFPS;

    /** Audio transmission frame rate. The unit of frame rate is f/s */
    public double audioSendFPS;

    /** Audio bit rate in kbps */
    public double audioKBPS;

    /** Local to server delay, in milliseconds */
    public int rtt;

    /** Packet loss rate, in percentage, 0.0 ~ 1.0 */
    public double packetLostRate;

    /** Published stream quality level */
    public ZegoStreamQualityLevel level;

    /** Whether to enable hardware encoding */
    public boolean isHardwareEncode;

    /** Video codec ID */
    public ZegoVideoCodecID videoCodecID;

    /** Total number of bytes sent, including audio, video, SEI */
    public double totalSendBytes;

    /** Number of audio bytes sent */
    public double audioSendBytes;

    /** Number of video bytes sent */
    public double videoSendBytes;

}
